arsenal.nlp package
===================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   arsenal.nlp.data
   arsenal.nlp.tests

Submodules
----------

arsenal.nlp.annotation module
-----------------------------

.. automodule:: arsenal.nlp.annotation
   :members:
   :undoc-members:
   :show-inheritance:

arsenal.nlp.evaluation module
-----------------------------

.. automodule:: arsenal.nlp.evaluation
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: arsenal.nlp
   :members:
   :undoc-members:
   :show-inheritance:
